@@ -98,15 +98,9 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "B",
 #' \item \code{cumulative} - whether the produced forecast was cumulative or not.
 #' \item \code{y} - original data.
 #' \item \code{holdout} - holdout part of the original data.
-#' \item \code{occurrence} - model of the class "oes" if the occurrence model was estimated.
-#' If the model is non-intermittent, then occurrence is \code{NULL}.
 #' \item \code{xreg} - provided vector or matrix of exogenous variables. If
 #' \code{xregDo="s"}, then this value will contain only selected exogenous variables.
-#' \item \code{updateX} - boolean, defining, if the states of exogenous variables
-#' were estimated as well.
 #' \item \code{initialX} - initial values for parameters of exogenous variables.
-#' \item \code{persistenceX} - persistence vector g for exogenous variables.
-#' \item \code{transitionX} - transition matrix F for exogenous variables.
 #' \item \code{ICs} - values of information criteria of the model. Includes
 #' AIC, AICc, BIC and BICc.
 #' \item \code{logLik} - log-likelihood of the function.
@@ -146,13 +140,6 @@ utils::globalVariables(c("measurementEstimate","transitionEstimate", "B",
 #' # Introduce exogenous variables
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118))}
 #'
-#' # Ask for their update
-#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118),updateX=TRUE)}
-#'
-#' # Do the same but now let's shrink parameters...
-#' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,xreg=c(1:118),updateX=TRUE,loss="TMSE")
-#' ourModel <- gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,loss="aTMSE")}
-#'
 #' # Or select the most appropriate one
 #' \dontrun{gum(rnorm(118,100,3),orders=c(1),lags=c(1),h=18,holdout=TRUE,xreg=c(1:118),xregDo="s")
 #'
@@ -168,12 +155,9 @@ gum <- function(y, orders=c(1,1), lags=c(1,frequency(y)), type=c("additive","mul
                 loss=c("MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
-                occurrence=c("none","auto","fixed","general","odds-ratio","inverse-odds-ratio","direct"),
-                oesmodel="MNN",
                 bounds=c("restricted","admissible","none"),
                 silent=c("all","graph","legend","output","none"),
-                xreg=NULL, xregDo=c("use","select"), initialX=NULL,
-                updateX=FALSE, persistenceX=NULL, transitionX=NULL, ...){
+                xreg=NULL, xregDo=c("use","select"), initialX=NULL, ...){
 # General Univariate Model function. Crazy thing...
 #
 #    Copyright (C) 2016 - Inf Ivan Svetunkov
@@ -181,13 +165,20 @@ gum <- function(y, orders=c(1,1), lags=c(1,frequency(y)), type=c("additive","mul
 # Start measuring the time of calculations
     startTime <- Sys.time();
 
-    ##### Check if data was used instead of y. Remove by 2.6.0 #####
-    y <- depricator(y, list(...), "data");
-    loss <- depricator(loss, list(...), "cfType");
-    interval <- depricator(interval, list(...), "intervals");
+    ### Depricate the old parameters
+    ellipsis <- list(...)
+    ellipsis <- depricator(ellipsis, "occurrence", "es");
+    ellipsis <- depricator(ellipsis, "oesmodel", "es");
+    ellipsis <- depricator(ellipsis, "updateX", "es");
+    ellipsis <- depricator(ellipsis, "persistenceX", "es");
+    ellipsis <- depricator(ellipsis, "transitionX", "es");
+    updateX <- FALSE;
+    persistenceX <- transitionX <- NULL;
+    occurrence <- "none";
+    oesmodel <- "MNN";
 
 # Add all the variables in ellipsis to current environment
-    list2env(list(...),environment());
+    list2env(ellipsis,environment());
 
     # If a previous model provided as a model, write down the variables
     if(exists("model",inherits=FALSE)){
@@ -473,8 +464,8 @@ CreatorGUM <- function(silentText=FALSE,...){
     errors <- rep(NA,obsInSample);
 
 ##### Prepare exogenous variables #####
-    xregdata <- ssXreg(y=y, xreg=xreg, updateX=updateX, ot=ot,
-                       persistenceX=persistenceX, transitionX=transitionX, initialX=initialX,
+    xregdata <- ssXreg(y=y, xreg=xreg, updateX=FALSE, ot=ot,
+                       persistenceX=NULL, transitionX=NULL, initialX=initialX,
                        obsInSample=obsInSample, obsAll=obsAll, obsStates=obsStates,
                        lagsModelMax=lagsModelMax, h=h, xregDo=xregDo, silent=silentText);
 
@@ -919,8 +910,8 @@ CreatorGUM <- function(silentText=FALSE,...){
                   nParam=parametersNumber,
                   fitted=yFitted,forecast=yForecast,lower=yLower,upper=yUpper,residuals=errors,
                   errors=errors.mat,s2=s2,interval=intervalType,level=level,cumulative=cumulative,
-                  y=y,holdout=yHoldout,occurrence=occurrenceModel,
-                  xreg=xreg,updateX=updateX,initialX=initialX,persistenceX=persistenceX,transitionX=transitionX,
+                  y=y,holdout=yHoldout,
+                  xreg=xreg,initialX=initialX,
                   ICs=ICs,logLik=logLik,lossValue=cfObjective,loss=loss,FI=FI,accuracy=errormeasures,
                   B=B);
     return(structure(model,class="smooth"));
