@@ -330,17 +330,6 @@ logLik.smooth.sim <- function(object,...){
     obs <- nobs(object);
     return(structure(object$logLik,nobs=obs,df=0,class="logLik"));
 }
-#' @export
-logLik.iss <- function(object,...){
-    if(is.null(object$logLik)){
-        warning("The likelihood of this model is unavailable.");
-        return(NULL);
-    }
-    else{
-        obs <- nobs(object);
-        return(structure(object$logLik,nobs=obs,df=nparam(object),class="logLik"));
-    }
-}
 
 #' @importFrom stats nobs
 #' @export
@@ -357,10 +346,6 @@ nobs.smooth.sim <- function(object, ...){
         return(nrow(object$data));
     }
 }
-#' @export
-nobs.iss <- function(object, ...){
-    return(length(object$fitted));
-}
 
 #' @importFrom greybox nparam
 
@@ -376,10 +361,6 @@ nparam.smooth <- function(object, ...){
     }
 }
 
-#' @export
-nparam.iss <- function(object, ...){
-    return(object$nParam);
-}
 
 #' Prediction Likelihood Score
 #'
@@ -714,7 +695,7 @@ NULL
 #'
 #' @aliases forecast forecast.smooth
 #' @param object Time series model for which forecasts are required.
-#' @param h Forecast horizon
+#' @param h Forecast horizon.
 #' @param interval Type of interval to construct. See \link[smooth]{es} for
 #' details.
 #' @param level Confidence level. Defines width of prediction interval.
@@ -738,7 +719,7 @@ NULL
 #' @seealso \code{\link[forecast]{ets}, \link[forecast]{forecast}}
 #' @references Hyndman, R.J., Koehler, A.B., Ord, J.K., and Snyder, R.D. (2008)
 #' Forecasting with exponential smoothing: the state space approach,
-#' Springer-Verlag. \url{http://www.exponentialsmoothing.net}.
+#' Springer-Verlag.
 #' @keywords ts univar
 #' @examples
 #'
@@ -856,15 +837,11 @@ forecast.oes <- function(object, h=10,
 #' @importFrom greybox actuals
 #' @export
 actuals.smooth <- function(object, ...){
-    return(window(object$y,start(object$y),end(object$fitted)));
+    return(window(object$y,start=start(object$y),end=end(object$fitted)));
 }
 #' @export
 actuals.smooth.forecast <- function(object, ...){
-    return(window(actuals(object$model),start(actuals(object$model)),end(fitted(object$model))));
-}
-#' @export
-actuals.iss <- function(object, ...){
-    return(window(actuals(object),start(actuals(object)),end(fitted(object))));
+    return(window(actuals(object$model),start=start(actuals(object$model)),end=end(fitted(object$model))));
 }
 
 #### Function extracts lags of provided model ####
@@ -1011,11 +988,6 @@ errorType.smooth <- function(object, ...){
 #' @export
 errorType.smooth.sim <- errorType.smooth;
 
-#' @export
-errorType.iss <- function(object, ...){
-    return(substr(modelType(object),1,1));
-}
-
 ##### Function returns the modelLags from the model - internal function #####
 modelLags.default <- function(object, ...){
     modelLags <- NA;
@@ -1131,11 +1103,6 @@ modelType.smooth <- function(object, ...){
 #' @export
 modelType.smooth.sim <- modelType.smooth;
 
-#' @export
-modelType.iss <- function(object, ...){
-    return(object$model);
-}
-
 #' @export
 modelType.oesg <- function(object, ...){
     return(modelType(object$modelA));
@@ -1401,17 +1368,6 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
             yName <- "Studentised";
         }
 
-        if(is.occurrence(x$occurrence)){
-            ellipsis$x <- ellipsis$x[actuals(x$occurrence)!=0];
-            ellipsis$y <- ellipsis$y[actuals(x$occurrence)!=0];
-        }
-
-        # Remove NAs
-        if(any(is.na(ellipsis$x))){
-            ellipsis$x <- ellipsis$x[!is.na(ellipsis$x)];
-            ellipsis$y <- ellipsis$y[!is.na(ellipsis$y)];
-        }
-
         if(!any(names(ellipsis)=="main")){
             ellipsis$main <- paste0(yName," Residuals vs Fitted");
         }
@@ -1432,15 +1388,18 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
             }
         }
 
-        zValues <- switch(x$loss,
-                          "MAE"=qlaplace(c((1-level)/2, (1+level)/2), 0, 1),
-                          "HAM"=qs(c((1-level)/2, (1+level)/2), 0, 1),
-                          qnorm(c((1-level)/2, (1+level)/2), 0, 1));
-        outliers <- which(ellipsis$y >zValues[2] | ellipsis$y <zValues[1]);
-        # cat(paste0(round(length(outliers)/length(ellipsis$y),3)*100,"% of values are outside the bounds\n"));
+        # Get the IDs of outliers and statistic
+        outliers <- outlierdummy(x, level=level, type=type);
+        outliersID <- outliers$id;
+        statistic <- outliers$statistic;
+
+        # Substitute zeroes with NAs if there was an occurrence
+        if(is.occurrence(x$occurrence)){
+            ellipsis$x[actuals(x$occurrence)==0] <- NA;
+        }
 
         if(!any(names(ellipsis)=="ylim")){
-            ellipsis$ylim <- range(c(ellipsis$y,zValues), na.rm=TRUE)*1.2;
+            ellipsis$ylim <- range(c(ellipsis$y,statistic), na.rm=TRUE)*1.2;
             if(legend){
                 if(legendPosition=="bottomright"){
                     ellipsis$ylim[1] <- ellipsis$ylim[1] - 0.2*diff(ellipsis$ylim);
@@ -1457,14 +1416,19 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
 
         do.call(plot,ellipsis);
         abline(h=0, col="grey", lty=2);
-        polygon(c(xRange,rev(xRange)),c(zValues[1],zValues[1],zValues[2],zValues[2]),
+        polygon(c(xRange,rev(xRange)),c(statistic[1],statistic[1],statistic[2],statistic[2]),
                 col="lightgrey", border=NA, density=10);
-        abline(h=zValues, col="red", lty=2);
-        if(length(outliers)>0){
-            points(ellipsis$x[outliers], ellipsis$y[outliers], pch=16);
-            text(ellipsis$x[outliers], ellipsis$y[outliers], labels=outliers, pos=(ellipsis$y[outliers]>0)*2+1);
+        abline(h=statistic, col="red", lty=2);
+        if(length(outliersID)>0){
+            points(ellipsis$x[outliersID], ellipsis$y[outliersID], pch=16);
+            text(ellipsis$x[outliersID], ellipsis$y[outliersID], labels=outliersID, pos=(ellipsis$y[outliersID]>0)*2+1);
         }
         if(lowess){
+            # Remove NAs
+            if(any(is.na(ellipsis$x))){
+                ellipsis$y <- ellipsis$y[!is.na(ellipsis$x)];
+                ellipsis$x <- ellipsis$x[!is.na(ellipsis$x)];
+            }
             lines(lowess(ellipsis$x, ellipsis$y), col="red");
         }
 
@@ -1610,10 +1574,6 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
             yName <- "Studentised";
         }
 
-        if(is.occurrence(x$occurrence)){
-            ellipsis$x <- ellipsis$x[actuals(x$occurrence)!=0];
-        }
-
         if(!any(names(ellipsis)=="main")){
             ellipsis$main <- paste0(yName," Residuals vs Time");
         }
@@ -1630,15 +1590,13 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
             ellipsis$type <- "l";
         }
 
-        zValues <- switch(x$loss,
-                          "MAE"=qlaplace(c((1-level)/2, (1+level)/2), 0, 1),
-                          "HAM"=qs(c((1-level)/2, (1+level)/2), 0, 1),
-                          qnorm(c((1-level)/2, (1+level)/2), 0, 1));
-        outliers <- which(ellipsis$x >zValues[2] | ellipsis$x <zValues[1]);
-
+        # Get the IDs of outliers and statistic
+        outliers <- outlierdummy(x, level=level, type=type);
+        outliersID <- outliers$id;
+        statistic <- outliers$statistic;
 
         if(!any(names(ellipsis)=="ylim")){
-            ellipsis$ylim <- c(-max(abs(ellipsis$x)),max(abs(ellipsis$x)))*1.2;
+            ellipsis$ylim <- range(c(ellipsis$x,statistic),na.rm=TRUE)*1.2;
         }
 
         if(legend){
@@ -1649,18 +1607,25 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
 
         # Start plotting
         do.call(plot,ellipsis);
-        if(length(outliers)>0){
-            points(time(ellipsis$x)[outliers], ellipsis$x[outliers], pch=16);
-            text(time(ellipsis$x)[outliers], ellipsis$x[outliers], labels=outliers, pos=(ellipsis$x[outliers]>0)*2+1);
+        if(is.occurrence(x$occurrence)){
+            points(ellipsis$x);
+        }
+        if(length(outliersID)>0){
+            points(time(ellipsis$x)[outliersID], ellipsis$x[outliersID], pch=16);
+            text(time(ellipsis$x)[outliersID], ellipsis$x[outliersID], labels=outliersID, pos=(ellipsis$x[outliersID]>0)*2+1);
         }
         if(lowess){
+            # Substitute NAs with the mean
+            if(any(is.na(ellipsis$x))){
+                ellipsis$x[is.na(ellipsis$x)] <- mean(ellipsis$x, na.rm=TRUE);
+            }
             lines(lowess(c(1:length(ellipsis$x)),ellipsis$x), col="red");
         }
         abline(h=0, col="grey", lty=2);
-        abline(h=zValues[1], col="red", lty=2);
-        abline(h=zValues[2], col="red", lty=2);
+        abline(h=statistic[1], col="red", lty=2);
+        abline(h=statistic[2], col="red", lty=2);
         polygon(c(1:nobs(x), c(nobs(x):1)),
-                c(rep(zValues[1],nobs(x)), rep(zValues[2],nobs(x))),
+                c(rep(statistic[1],nobs(x)), rep(statistic[2],nobs(x))),
                 col="lightgrey", border=NA, density=10);
         if(legend){
             legend(legendPosition,legend=c("Residuals",paste0(level*100,"% prediction interval")),
@@ -1704,17 +1669,17 @@ plot.smooth <- function(x, which=c(1,2,4,6), level=0.95, legend=FALSE,
             theValues <- pacf(as.vector(residuals(x)), plot=FALSE, na.action=na.pass);
         }
         ellipsis$x <- theValues$acf[-1];
-        zValues <- qnorm(c((1-level)/2, (1+level)/2),0,sqrt(1/nobs(x)));
+        statistic <- qnorm(c((1-level)/2, (1+level)/2),0,sqrt(1/nobs(x)));
 
         ellipsis$type <- "h"
 
         do.call(plot,ellipsis);
         abline(h=0, col="black", lty=1);
-        abline(h=zValues, col="red", lty=2);
-        if(any(ellipsis$x>zValues[2] | ellipsis$x<zValues[1])){
-            outliers <- which(ellipsis$x >zValues[2] | ellipsis$x <zValues[1]);
-            points(outliers, ellipsis$x[outliers], pch=16);
-            text(outliers, ellipsis$x[outliers], labels=outliers, pos=(ellipsis$x[outliers]>0)*2+1);
+        abline(h=statistic, col="red", lty=2);
+        if(any(ellipsis$x>statistic[2] | ellipsis$x<statistic[1])){
+            outliersID <- which(ellipsis$x >statistic[2] | ellipsis$x <statistic[1]);
+            points(outliersID, ellipsis$x[outliersID], pch=16);
+            text(outliersID, ellipsis$x[outliersID], labels=outliersID, pos=(ellipsis$x[outliersID]>0)*2+1);
         }
     }
 
@@ -1904,7 +1869,7 @@ plot.smooth.forecast <- function(x, ...){
     yActuals <- actuals(x$model);
     if(!is.null(x$model$holdout)){
         yActuals <- ts(c(yActuals,x$model$holdout), start=start(yActuals), frequency=frequency(yActuals));
-        yActuals <- window(yActuals, start(yActuals), min(tail(time(x$mean),1),tail(time(yActuals),1)));
+        yActuals <- window(yActuals, start=start(yActuals), end=min(tail(time(x$mean),1),tail(time(yActuals),1)));
     }
     if(!any(x$interval==c("none","n"))){
         graphmaker(yActuals,x$mean,fitted(x$model),x$lower,x$upper,x$level,...);
@@ -2022,7 +1987,7 @@ print.smooth <- function(x, ...){
 
     ssOutput(x$timeElapsed, x$model, persistence=x$persistence, transition=x$transition, measurement=x$measurement,
              phi=x$phi, ARterms=x$AR, MAterms=x$MA, constant=x$constant, a=x$a, b=x$b,initialType=x$initialType,
-             nParam=x$nParam, s2=x$s2, hadxreg=!is.null(x$xreg), wentwild=x$updateX,
+             nParam=x$nParam, s2=x$s2, hadxreg=!is.null(x$xreg), wentwild=FALSE,
              loss=x$loss, cfObjective=x$lossValue, interval=interval, cumulative=cumulative,
              intervalType=intervalType, level=x$level, ICs=x$ICs,
              holdout=holdout, insideinterval=insideinterval, errormeasures=x$accuracy,
@@ -2173,46 +2138,6 @@ print.smooth.forecast <- function(x, ...){
     print(output);
 }
 
-#' @export
-print.iss <- function(x, ...){
-    intermittent <- x$intermittent
-    if(intermittent=="i"){
-        intermittent <- "Interval-based";
-    }
-    else if(intermittent=="p"){
-        intermittent <- "Probability-based";
-    }
-    else if(intermittent=="f"){
-        intermittent <- "Fixed probability";
-    }
-    else if(intermittent=="l"){
-        intermittent <- "Logistic probability";
-    }
-    else if(intermittent=="s"){
-        intermittent <- "Interval-based with SBA correction";
-    }
-    else{
-        intermittent <- "None";
-    }
-    ICs <- round(c(AIC(x),AICc(x),BIC(x),BICc(x)),4);
-    names(ICs) <- c("AIC","AICc","BIC","BICc");
-    cat(paste0("Intermittent state space model estimated: ",intermittent,"\n"));
-    if(!is.null(x$model)){
-        cat(paste0("Underlying ETS model: ",x$model,"\n"));
-    }
-    if(!is.null(x$persistence)){
-        cat("Smoothing parameters:\n");
-        print(round(x$persistence,3));
-    }
-    if(!is.null(x$initial)){
-        cat("Vector of initials:\n");
-        print(round(x$initial,3));
-    }
-    # cat(paste0("Probability forecast: ",round(x$forecast[1],3),"\n"));
-    cat("Information criteria: \n");
-    print(ICs);
-}
-
 #' @export
 print.oes <- function(x, ...){
     ellipsis <- list(...);
@@ -2313,14 +2238,19 @@ rstandard.smooth <- function(model, ...){
 
     # If this is an occurrence model, then only modify the non-zero obs
     if(is.occurrence(model$occurrence)){
-        residsToGo <- which(actuals(model$occurrence)!=0);
+        residsToGo <- (actuals(model$occurrence)!=0);
     }
     else{
-        residsToGo <- c(1:obs);
+        residsToGo <- rep(TRUE,obs);
     }
 
-    errors <- residuals(model);
-    return((errors - mean(errors[residsToGo], na.rm=TRUE)) / sqrt(sigma(model)^2 * obs / df));
+    errors <- residuals(model, ...);
+    errors[] <- (errors - mean(errors[residsToGo], na.rm=TRUE)) / sqrt(sigma(model)^2 * obs / df);
+    # Fill in values with NAs if there is occurrence model
+    if(is.occurrence(model$occurrence)){
+        errors[!residsToGo] <- NA;
+    }
+    return(errors);
 }
 
 #' @importFrom stats rstudent
@@ -2328,29 +2258,62 @@ rstandard.smooth <- function(model, ...){
 rstudent.smooth <- function(model, ...){
     obs <- nobs(model);
     df <- obs - nparam(model) - 1;
-    rstudentised <- errors <- residuals(model);
-    errors[] <- errors - mean(errors, na.rm=TRUE);
     # If this is an occurrence model, then only modify the non-zero obs
     if(is.occurrence(model$occurrence)){
-        residsToGo <- which(actuals(model$occurrence)!=0);
+        residsToGo <- (actuals(model$occurrence)!=0);
     }
     else{
-        residsToGo <- c(1:obs);
+        residsToGo <- rep(TRUE,obs);
     }
+    rstudentised <- errors <- residuals(model, ...);
+    errors[] <- errors - mean(errors, na.rm=TRUE);
     # Prepare the residuals
     if(errorType(model)=="M"){
-        for(i in residsToGo){
+        for(i in which(residsToGo)){
             rstudentised[i] <- errors[i] / sqrt(sum(errors[-i]^2, na.rm=TRUE) / df);
         }
     }
     else{
-        for(i in residsToGo){
+        for(i in which(residsToGo)){
             rstudentised[i] <- errors[i] / sqrt(sum(errors[-i]^2, na.rm=TRUE) / df);
         }
     }
+    # Fill in values with NAs if there is occurrence model
+    if(is.occurrence(model$occurrence)){
+        rstudentised[!residsToGo] <- NA;
+    }
+
     return(rstudentised);
 }
 
+#' @importFrom greybox outlierdummy
+#' @export
+outlierdummy.smooth <- function(object, level=0.999, type=c("rstandard","rstudent"), ...){
+    # Function returns the matrix of dummies with outliers
+    type <- match.arg(type);
+    errors <- switch(type,"rstandard"=rstandard(object),"rstudent"=rstudent(object));
+    statistic <- switch(object$loss,
+                      "MAE"=,"MAEh"=,"MACE"=,"TMAE"=,"GTMAE"=qlaplace(c((1-level)/2, (1+level)/2), 0, 1),
+                      "HAM"=,"HAMh"=,"CHAM"=,"THAM"=,"GTHAM"=qs(c((1-level)/2, (1+level)/2), 0, 1),
+                      qnorm(c((1-level)/2, (1+level)/2), 0, 1));
+
+    outliersID <- which(errors>statistic[2] | errors<statistic[1]);
+    outliersNumber <- length(outliersID);
+    if(outliersNumber>0){
+        outliers <- ts(matrix(0, nobs(object), outliersNumber,
+                              dimnames=list(NULL,
+                                            paste0("outlier",c(1:outliersNumber)))),
+                       start=start(actuals(object)), frequency=frequency(actuals(object)));
+        outliers[cbind(outliersID,c(1:outliersNumber))] <- 1;
+    }
+    else{
+        outliers <- NULL;
+    }
+
+    return(structure(list(outliers=outliers, statistic=statistic, id=outliersID,
+                          level=level, type=type),
+                     class="outlierdummy"));
+}
 
 
 #### Simulate data using provided object ####
@@ -2546,8 +2509,3 @@ summary.smooth <- function(object, ...){
 summary.smooth.forecast <- function(object, ...){
     print(object);
 }
-
-#' @export
-summary.iss <- function(object, ...){
-    print(object);
-}
