@@ -187,11 +187,6 @@ ves <- function(y, model="ANN", persistence=c("common","individual","dependent",
 # Start measuring the time of calculations
     startTime <- Sys.time();
 
-    ##### Check if data was used instead of y. Remove by 2.6.0 #####
-    y <- depricator(y, list(...), "data");
-    loss <- depricator(loss, list(...), "cfType");
-    interval <- depricator(interval, list(...), "intervals");
-
     # Check if the old value of parameters are passed
     if(any(c("group","g") %in% c(persistence, transition, phi, initial, initialSeason))){
         warning("You are using the old value of the parameters. We now have 'common' instead of 'group'.");
@@ -248,10 +243,34 @@ ves <- function(y, model="ANN", persistence=c("common","individual","dependent",
 
 ##### Cost Function for VES #####
 CF <- function(B){
-    elements <- BasicInitialiserVES(matvt,matF,matG,matW,B);
+    elements <- BasicInitialiserVES(matvt, matF, matG, matW, B);
 
-    cfRes <- vOptimiserWrap(yInSample, elements$matvt, elements$matF, elements$matW, elements$matG,
-                            lagsModel, Etype, Ttype, Stype, loss, normalizer, bounds, ot, otObs);
+    # Check the bounds
+    if(bounds=="a"){
+        eigenValues <- eigen(elements$matF - elements$matG %*% elements$matW, only.values=TRUE, symmetric=TRUE)$values;
+        if(max(abs(eigenValues)>(1 + 1E-50))){
+            return(max(abs(eigenValues))*1E+100);
+        }
+    }
+
+    # Fit the model
+    fitting <- vFitterWrap(yInSample, elements$matvt, elements$matF, elements$matW, elements$matG,
+                           lagsModel, Etype, Ttype, Stype, ot);
+
+    # Calculate the loss
+    if(loss=="l"){
+        cfRes <- suppressWarnings(log(det((fitting$errors / normalizer) %*% t(fitting$errors / normalizer) / otObs)) +
+                                      nSeries * log(normalizer^2));
+    }
+    else if(loss=="d"){
+        cfRes <- sum(log(apply(fitting$errors^2, 2, sum) / obsInSample));
+    }
+    else{
+        cfRes <- sum(apply(fitting$errors^2, 2, sum) / obsInSample);
+    }
+
+    # cfRes <- vOptimiserWrap(yInSample, elements$matvt, elements$matF, elements$matW, elements$matG,
+    #                         lagsModel, Etype, Ttype, Stype, loss, normalizer, bounds, ot, otObs);
     # multisteps, initialType, bounds,
 
     if(is.nan(cfRes) | is.na(cfRes) | is.infinite(cfRes)){
@@ -899,6 +918,8 @@ EstimatorVES <- function(...){
         }
     }
 
+    normalizer <- sum(colMeans(abs(diff(t(yInSample))),na.rm=TRUE));
+
     # Parameters are chosen to speed up the optimisation process and have decent accuracy
     res <- nloptr(B, CF, lb=BList$BLower, ub=BList$BUpper,
                   opts=list(algorithm=algorithm1, xtol_rel=xtol_rel1, maxeval=maxeval));
