@@ -24,16 +24,9 @@ test_that("Test initials, a and b of CES on N2568$x", {
     expect_equal(ces(Mcomp::M3$N2568$x, seasonality="f", b=testModel$b, silent=TRUE)$b, testModel$b);
 })
 
-# Test exogenous (normal + updateX) with CES
+# Test selection of exogenous with CES
 x <- cbind(c(rep(0,25),1,rep(0,43)),c(rep(0,10),1,rep(0,58)));
 y <- ts(c(Mcomp::M3$N1457$x,Mcomp::M3$N1457$xx),frequency=12);
-testModel <- ces(y, h=18, holdout=TRUE, xreg=x, updateX=TRUE, silent=TRUE, loss="aTMSE", interval="sp")
-test_that("Check exogenous variables for CESX on N1457", {
-    expect_equal(suppressWarnings(ces(y, h=18, holdout=TRUE, xreg=x, silent=TRUE)$model), testModel$model);
-    expect_equal(suppressWarnings(forecast(testModel, h=18, holdout=FALSE)$method), testModel$model);
-})
-
-# Test selection of exogenous with CES
 testModel <- ces(y, h=18, holdout=TRUE, xreg=xregExpander(x), silent=TRUE, xregDo="select")
 test_that("Select exogenous variables for CESX on N1457 with selection", {
     expect_equal(suppressWarnings(ncol(testModel$xreg)),3);
